@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018-2023,2024 Thomas E. Dickey                                *
+ * Copyright 2018-2024,2025 Thomas E. Dickey                                *
  * Copyright 1998-2016,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -33,7 +33,7 @@
  *     and: Thomas E. Dickey                        1996-on                 *
  ****************************************************************************/
 
-/* $Id: curses.h.in,v 1.282 2024/01/19 11:50:07 tom Exp $ */
+/* $Id: curses.h.in,v 1.291 2025/02/23 01:33:32 tom Exp $ */
 
 #ifndef __NCURSES_H
 #define __NCURSES_H
@@ -72,12 +72,12 @@
 
 /* These are defined only in curses.h, and are used for conditional compiles */
 #define NCURSES_VERSION_MAJOR 6
-#define NCURSES_VERSION_MINOR 4
-#define NCURSES_VERSION_PATCH 20240330
+#define NCURSES_VERSION_MINOR 5
+#define NCURSES_VERSION_PATCH 20250308
 
 /* This is defined in more than one ncurses header, for identification */
 #undef  NCURSES_VERSION
-#define NCURSES_VERSION "6.4"
+#define NCURSES_VERSION "6.5"
 
 /*
  * Identify the mouse encoding version.
@@ -125,10 +125,10 @@
  * doing so makes it incompatible with other implementations of X/Open Curses.
  */
 #undef  NCURSES_CONST
-#define NCURSES_CONST const
+#define NCURSES_CONST const	/* for old compilers */
 
 #undef NCURSES_INLINE
-#define NCURSES_INLINE inline
+#define NCURSES_INLINE inline	/* for old compilers */
 
 /*
  * The standard type used for color values, and for color-pairs.  The latter
@@ -296,7 +296,7 @@ typedef unsigned char NCURSES_BOOL;
 #include <stdbool.h>
 /* use whatever the C compiler decides bool really is */
 #define NCURSES_BOOL bool
-#else
+#elif !defined(__cplusplus) && !0
 /* there is no predefined bool - use our own */
 #undef bool
 #define bool NCURSES_BOOL
@@ -311,7 +311,7 @@ extern "C" {
 #define NCURSES_CAST(type,value) (type)(value)
 #endif
 
-#define NCURSES_OK_ADDR(p) (0 != NCURSES_CAST(const void *, (p)))
+#define NCURSES_OK_ADDR(p) (NULL != NCURSES_CAST(const void *, (p)))
 
 /*
  * X/Open attributes.  In the ncurses implementation, they are identical to the
@@ -491,7 +491,7 @@ typedef struct
     wchar_t	chars[CCHARW_MAX];
 #if 0
 #undef NCURSES_EXT_COLORS
-#define NCURSES_EXT_COLORS 20240330
+#define NCURSES_EXT_COLORS 20250308
     int		ext_color;	/* color pair, must be more than 16-bits */
 #endif
 }
@@ -833,7 +833,7 @@ extern NCURSES_EXPORT(int) vline (chtype, int);				/* generated */
 extern NCURSES_EXPORT(int) vwprintw (WINDOW *, const char *, va_list) GCC_DEPRECATED(use vw_printw)	/* implemented */
 		GCC_PRINTFLIKE(2,0);
 extern NCURSES_EXPORT(int) vw_printw (WINDOW *, const char *, va_list)	/* implemented */
-		GCC_PRINTFLIKE(2,0);	
+		GCC_PRINTFLIKE(2,0);
 extern NCURSES_EXPORT(int) vwscanw (WINDOW *, const char *, va_list) GCC_DEPRECATED(use vw_scanw)	/* implemented */
 		GCC_SCANFLIKE(2,0);
 extern NCURSES_EXPORT(int) vw_scanw (WINDOW *, const char *, va_list)	/* implemented */
@@ -938,7 +938,7 @@ extern NCURSES_EXPORT(int) getpary (const WINDOW *);			/* generated */
  */
 #if 1
 #undef  NCURSES_EXT_FUNCS
-#define NCURSES_EXT_FUNCS 20240330
+#define NCURSES_EXT_FUNCS 20250308
 typedef int (*NCURSES_WINDOW_CB)(WINDOW *, void *);
 typedef int (*NCURSES_SCREEN_CB)(SCREEN *, void *);
 extern NCURSES_EXPORT(int) alloc_pair (int, int);
@@ -1009,7 +1009,7 @@ extern NCURSES_EXPORT(int) wgetscrreg (const WINDOW *, int *, int *); /* generat
  */
 #if 1
 #undef  NCURSES_SP_FUNCS
-#define NCURSES_SP_FUNCS 20240330
+#define NCURSES_SP_FUNCS 20250308
 #define NCURSES_SP_NAME(name) name##_sp
 
 /* Define the sp-funcs helper function */
@@ -1534,7 +1534,7 @@ extern NCURSES_EXPORT_VAR(int) TABSIZE;
 #define KEY_SRESET	0530		/* Soft (partial) reset (unreliable) */
 #define KEY_RESET	0531		/* Reset or hard reset (unreliable) */
 /*
- * These definitions were generated by ./MKkey_defs.sh /var/tmp/portage/sys-libs/ncurses-6.4_p20240330/work/ncurses-6.4/include/Caps /var/tmp/portage/sys-libs/ncurses-6.4_p20240330/work/ncurses-6.4/include/Caps-ncurses
+ * These definitions were generated by ./MKkey_defs.sh /usr/riscv64-unknown-linux-gnu/tmp/portage/sys-libs/ncurses-6.5_p20250308/work/ncurses-6.5/include/Caps /usr/riscv64-unknown-linux-gnu/tmp/portage/sys-libs/ncurses-6.5_p20250308/work/ncurses-6.5/include/Caps-ncurses
  */
 #define KEY_DOWN	0402		/* down-arrow key */
 #define KEY_UP		0403		/* up-arrow key */
