@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018-2023,2024 Thomas E. Dickey                                *
+ * Copyright 2018-2024,2025 Thomas E. Dickey                                *
  * Copyright 1998-2016,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -33,7 +33,7 @@
  *     and: Thomas E. Dickey                        1996-on                 *
  ****************************************************************************/
 
-/* $Id: curses.h.in,v 1.282 2024/01/19 11:50:07 tom Exp $ */
+/* $Id: curses.h.in,v 1.295 2025/05/24 16:38:03 tom Exp $ */
 
 #ifndef __NCURSES_H
 #define __NCURSES_H
@@ -72,12 +72,12 @@
 
 /* These are defined only in curses.h, and are used for conditional compiles */
 #define NCURSES_VERSION_MAJOR 6
-#define NCURSES_VERSION_MINOR 4
-#define NCURSES_VERSION_PATCH 20240330
+#define NCURSES_VERSION_MINOR 5
+#define NCURSES_VERSION_PATCH 20250531
 
 /* This is defined in more than one ncurses header, for identification */
 #undef  NCURSES_VERSION
-#define NCURSES_VERSION "6.4"
+#define NCURSES_VERSION "6.5"
 
 /*
  * Identify the mouse encoding version.
@@ -125,10 +125,10 @@
  * doing so makes it incompatible with other implementations of X/Open Curses.
  */
 #undef  NCURSES_CONST
-#define NCURSES_CONST const
+#define NCURSES_CONST const	/* for old compilers */
 
 #undef NCURSES_INLINE
-#define NCURSES_INLINE inline
+#define NCURSES_INLINE inline	/* for old compilers */
 
 /*
  * The standard type used for color values, and for color-pairs.  The latter
@@ -175,14 +175,14 @@
  * KEY_RESIZE is an extended feature that relies upon the SIGWINCH handler
  * in ncurses.
  */
-#if 1
+#if 1	/* NCURSES_EXT_FUNCS */
 #ifndef NCURSES_SIGWINCH
 #define NCURSES_SIGWINCH 1
 #endif
 #else
 #undef NCURSES_SIGWINCH
 #define NCURSES_SIGWINCH 0
-#endif
+#endif /* NCURSES_EXT_FUNCS */
 
 /*
  * In certain environments, we must work around linker problems for data
@@ -296,7 +296,7 @@ typedef unsigned char NCURSES_BOOL;
 #include <stdbool.h>
 /* use whatever the C compiler decides bool really is */
 #define NCURSES_BOOL bool
-#else
+#elif !defined(__cplusplus) && !0
 /* there is no predefined bool - use our own */
 #undef bool
 #define bool NCURSES_BOOL
@@ -311,7 +311,7 @@ extern "C" {
 #define NCURSES_CAST(type,value) (type)(value)
 #endif
 
-#define NCURSES_OK_ADDR(p) (0 != NCURSES_CAST(const void *, (p)))
+#define NCURSES_OK_ADDR(p) (NULL != NCURSES_CAST(const void *, (p)))
 
 /*
  * X/Open attributes.  In the ncurses implementation, they are identical to the
@@ -489,11 +489,14 @@ typedef struct
 {
     attr_t	attr;
     wchar_t	chars[CCHARW_MAX];
-#if 0
+#if 0	/* NCURSES_EXT_COLORS */
 #undef NCURSES_EXT_COLORS
-#define NCURSES_EXT_COLORS 20240330
+#define NCURSES_EXT_COLORS 20250531
     int		ext_color;	/* color pair, must be more than 16-bits */
+#if 0	/* NCURSES_RGB_COLORS */
+    int		rgb_color;	/* extra data for direct-color (rgb) */
 #endif
+#endif /* NCURSES_EXT_COLORS */
 }
 cchar_t;
 
@@ -833,7 +836,7 @@ extern NCURSES_EXPORT(int) vline (chtype, int);				/* generated */
 extern NCURSES_EXPORT(int) vwprintw (WINDOW *, const char *, va_list) GCC_DEPRECATED(use vw_printw)	/* implemented */
 		GCC_PRINTFLIKE(2,0);
 extern NCURSES_EXPORT(int) vw_printw (WINDOW *, const char *, va_list)	/* implemented */
-		GCC_PRINTFLIKE(2,0);	
+		GCC_PRINTFLIKE(2,0);
 extern NCURSES_EXPORT(int) vwscanw (WINDOW *, const char *, va_list) GCC_DEPRECATED(use vw_scanw)	/* implemented */
 		GCC_SCANFLIKE(2,0);
 extern NCURSES_EXPORT(int) vw_scanw (WINDOW *, const char *, va_list)	/* implemented */
@@ -936,9 +939,9 @@ extern NCURSES_EXPORT(int) getpary (const WINDOW *);			/* generated */
 /*
  * These functions are extensions - not in X/Open Curses.
  */
-#if 1
+#if 1	/* NCURSES_EXT_FUNCS */
 #undef  NCURSES_EXT_FUNCS
-#define NCURSES_EXT_FUNCS 20240330
+#define NCURSES_EXT_FUNCS 20250531
 typedef int (*NCURSES_WINDOW_CB)(WINDOW *, void *);
 typedef int (*NCURSES_SCREEN_CB)(SCREEN *, void *);
 extern NCURSES_EXPORT(int) alloc_pair (int, int);
@@ -999,17 +1002,17 @@ extern NCURSES_EXPORT(bool) is_syncok (const WINDOW *);		/* generated */
 extern NCURSES_EXPORT(int) wgetdelay (const WINDOW *);		/* generated */
 extern NCURSES_EXPORT(int) wgetscrreg (const WINDOW *, int *, int *); /* generated */
 
-#else
+#else /* !NCURSES_EXT_FUNCS */
 #define curses_version() NCURSES_VERSION
-#endif
+#endif /* NCURSES_EXT_FUNCS */
 
 /*
  * Extra extension-functions, which pass a SCREEN pointer rather than using
  * a global variable SP.
  */
-#if 1
+#if 1	/* NCURSES_SP_FUNCS */
 #undef  NCURSES_SP_FUNCS
-#define NCURSES_SP_FUNCS 20240330
+#define NCURSES_SP_FUNCS 20250531
 #define NCURSES_SP_NAME(name) name##_sp
 
 /* Define the sp-funcs helper function */
@@ -1091,7 +1094,7 @@ extern NCURSES_EXPORT(void) NCURSES_SP_NAME(use_env) (SCREEN*, bool); /* impleme
 extern NCURSES_EXPORT(void) NCURSES_SP_NAME(use_tioctl) (SCREEN*, bool); /* implemented:SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(vidattr) (SCREEN*, chtype);	/* implemented:SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(vidputs) (SCREEN*, chtype, NCURSES_SP_OUTC); /* implemented:SP_FUNC */
-#if 1
+#if 1	/* NCURSES_EXT_FUNCS */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(alloc_pair) (SCREEN*, int, int); /* implemented:EXT_SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(assume_default_colors) (SCREEN*, int, int);	/* implemented:EXT_SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(define_key) (SCREEN*, const char *, int);	/* implemented:EXT_SP_FUNC */
@@ -1119,13 +1122,13 @@ extern NCURSES_EXPORT(int) NCURSES_SP_NAME(set_escdelay) (SCREEN*, int);	/* impl
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(set_tabsize) (SCREEN*, int);	/* implemented:EXT_SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(use_default_colors) (SCREEN*);	/* implemented:EXT_SP_FUNC */
 extern NCURSES_EXPORT(int) NCURSES_SP_NAME(use_legacy_coding) (SCREEN*, int);	/* implemented:EXT_SP_FUNC */
-#endif
-#else
+#endif /* NCURSES_EXT_FUNCS */
+#else /* !NCURSES_SP_FUNCS */
 #undef  NCURSES_SP_FUNCS
 #define NCURSES_SP_FUNCS 0
 #define NCURSES_SP_NAME(name) name
 #define NCURSES_SP_OUTC NCURSES_OUTC
-#endif
+#endif /* NCURSES_SP_FUNCS */
 
 /* attributes */
 
@@ -1143,8 +1146,12 @@ extern NCURSES_EXPORT(int) NCURSES_SP_NAME(use_legacy_coding) (SCREEN*, int);	/*
 #define A_DIM		NCURSES_BITS(1U,12)
 #define A_BOLD		NCURSES_BITS(1U,13)
 #define A_ALTCHARSET	NCURSES_BITS(1U,14)
+
+/* SVr4 curses marks these as "subject to change" */
 #define A_INVIS		NCURSES_BITS(1U,15)
 #define A_PROTECT	NCURSES_BITS(1U,16)
+
+/* X/Open features not found in SVr4 curses */
 #define A_HORIZONTAL	NCURSES_BITS(1U,17)
 #define A_LEFT		NCURSES_BITS(1U,18)
 #define A_LOW		NCURSES_BITS(1U,19)
@@ -1152,9 +1159,14 @@ extern NCURSES_EXPORT(int) NCURSES_SP_NAME(use_legacy_coding) (SCREEN*, int);	/*
 #define A_TOP		NCURSES_BITS(1U,21)
 #define A_VERTICAL	NCURSES_BITS(1U,22)
 
-#if 1
+#if 1	/* NCURSES_EXT_FUNCS */
 #define A_ITALIC	NCURSES_BITS(1U,23)	/* ncurses extension */
-#endif
+#if 0	/* NCURSES_RGB_COLORS */
+#define A_FOREGROUND	NCURSES_BITS(1U,17)	/* ncurses extension */
+#define A_BACKGROUND	NCURSES_BITS(1U,18)	/* ncurses extension */
+#define A_DIRECT	(A_FOREGROUND|A_BACKGROUND)
+#endif /* NCURSES_RGB_COLORS */
+#endif /* NCURSES_EXT_FUNCS */
 
 /*
  * Most of the pseudo functions are macros that either provide compatibility
@@ -1441,7 +1453,7 @@ NCURSES_EXPORT(int) vsscanf(const char *, const char *, va_list);
 /*
  * These macros are extensions - not in X/Open Curses.
  */
-#if 1
+#if 1	/* NCURSES_EXT_FUNCS */
 #if !NCURSES_OPAQUE
 #define is_cleared(win)		(NCURSES_OK_ADDR(win) ? (win)->_clear : FALSE)
 #define is_idcok(win)		(NCURSES_OK_ADDR(win) ? (win)->_idcok : FALSE)
@@ -1459,7 +1471,7 @@ NCURSES_EXPORT(int) vsscanf(const char *, const char *, va_list);
 #define wgetparent(win)		(NCURSES_OK_ADDR(win) ? (win)->_parent : 0)
 #define wgetscrreg(win,t,b)	(NCURSES_OK_ADDR(win) ? (*(t) = (win)->_regtop, *(b) = (win)->_regbottom, OK) : ERR)
 #endif
-#endif
+#endif /* NCURSES_EXT_FUNCS */
 
 /*
  * X/Open says this returns a bool; SVr4 also checked for out-of-range line.
@@ -1534,7 +1546,7 @@ extern NCURSES_EXPORT_VAR(int) TABSIZE;
 #define KEY_SRESET	0530		/* Soft (partial) reset (unreliable) */
 #define KEY_RESET	0531		/* Reset or hard reset (unreliable) */
 /*
- * These definitions were generated by ./MKkey_defs.sh /var/tmp/portage/sys-libs/ncurses-6.4_p20240330/work/ncurses-6.4/include/Caps /var/tmp/portage/sys-libs/ncurses-6.4_p20240330/work/ncurses-6.4/include/Caps-ncurses
+ * These definitions were generated by ./MKkey_defs.sh /var/tmp/portage/sys-libs/ncurses-6.5_p20250531-r1/work/ncurses-6.5/include/Caps /var/tmp/portage/sys-libs/ncurses-6.5_p20250531-r1/work/ncurses-6.5/include/Caps-ncurses
  */
 #define KEY_DOWN	0402		/* down-arrow key */
 #define KEY_UP		0403		/* up-arrow key */
@@ -1630,7 +1642,7 @@ extern NCURSES_EXPORT_VAR(int) TABSIZE;
 #endif
 
 #define KEY_MAX		0777		/* Maximum key value is 0632 */
-/* $Id: curses.tail,v 1.27 2023/08/05 19:43:46 tom Exp $ */
+/* $Id: curses.tail,v 1.28 2025/05/17 20:32:15 tom Exp $ */
 /*
  * vile:cmode:
  * This file is part of ncurses, designed to be appended after curses.h.in
@@ -1694,7 +1706,51 @@ extern NCURSES_EXPORT_VAR(int) TABSIZE;
 #define	BUTTON_ALT		NCURSES_MOUSE_MASK(6, 0004L)
 #define	REPORT_MOUSE_POSITION	NCURSES_MOUSE_MASK(6, 0010L)
 
-#else
+/*
+ * If mmask_T is 64-bits, we can define another 6 button stanzas, for a total
+ * of 11, which happens to be the maximum number supported in the X11 protocol.
+ */
+#if NCURSES_MOUSE_VERSION > 2
+
+#define	BUTTON6_RELEASED	NCURSES_MOUSE_MASK(6, NCURSES_BUTTON_RELEASED)
+#define	BUTTON6_PRESSED		NCURSES_MOUSE_MASK(6, NCURSES_BUTTON_PRESSED)
+#define	BUTTON6_CLICKED		NCURSES_MOUSE_MASK(6, NCURSES_BUTTON_CLICKED)
+#define	BUTTON6_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(6, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON6_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(6, NCURSES_TRIPLE_CLICKED)
+
+#define	BUTTON7_RELEASED	NCURSES_MOUSE_MASK(7, NCURSES_BUTTON_RELEASED)
+#define	BUTTON7_PRESSED		NCURSES_MOUSE_MASK(7, NCURSES_BUTTON_PRESSED)
+#define	BUTTON7_CLICKED		NCURSES_MOUSE_MASK(7, NCURSES_BUTTON_CLICKED)
+#define	BUTTON7_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(7, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON7_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(7, NCURSES_TRIPLE_CLICKED)
+
+#define	BUTTON8_RELEASED	NCURSES_MOUSE_MASK(8, NCURSES_BUTTON_RELEASED)
+#define	BUTTON8_PRESSED		NCURSES_MOUSE_MASK(8, NCURSES_BUTTON_PRESSED)
+#define	BUTTON8_CLICKED		NCURSES_MOUSE_MASK(8, NCURSES_BUTTON_CLICKED)
+#define	BUTTON8_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(8, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON8_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(8, NCURSES_TRIPLE_CLICKED)
+
+#define	BUTTON9_RELEASED	NCURSES_MOUSE_MASK(9, NCURSES_BUTTON_RELEASED)
+#define	BUTTON9_PRESSED		NCURSES_MOUSE_MASK(9, NCURSES_BUTTON_PRESSED)
+#define	BUTTON9_CLICKED		NCURSES_MOUSE_MASK(9, NCURSES_BUTTON_CLICKED)
+#define	BUTTON9_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(9, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON9_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(9, NCURSES_TRIPLE_CLICKED)
+
+#define	BUTTON10_RELEASED	NCURSES_MOUSE_MASK(10, NCURSES_BUTTON_RELEASED)
+#define	BUTTON10_PRESSED	NCURSES_MOUSE_MASK(10, NCURSES_BUTTON_PRESSED)
+#define	BUTTON10_CLICKED	NCURSES_MOUSE_MASK(10, NCURSES_BUTTON_CLICKED)
+#define	BUTTON10_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(10, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON10_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(10, NCURSES_TRIPLE_CLICKED)
+
+#define	BUTTON11_RELEASED	NCURSES_MOUSE_MASK(11, NCURSES_BUTTON_RELEASED)
+#define	BUTTON11_PRESSED	NCURSES_MOUSE_MASK(11, NCURSES_BUTTON_PRESSED)
+#define	BUTTON11_CLICKED	NCURSES_MOUSE_MASK(11, NCURSES_BUTTON_CLICKED)
+#define	BUTTON11_DOUBLE_CLICKED	NCURSES_MOUSE_MASK(11, NCURSES_DOUBLE_CLICKED)
+#define	BUTTON11_TRIPLE_CLICKED	NCURSES_MOUSE_MASK(11, NCURSES_TRIPLE_CLICKED)
+
+#endif
+
+#else	/* NCURSES_MOUSE_VERSION == 1 */
 
 #define	BUTTON1_RESERVED_EVENT	NCURSES_MOUSE_MASK(1, NCURSES_RESERVED_EVENT)
 #define	BUTTON2_RESERVED_EVENT	NCURSES_MOUSE_MASK(2, NCURSES_RESERVED_EVENT)
@@ -1706,7 +1762,7 @@ extern NCURSES_EXPORT_VAR(int) TABSIZE;
 #define	BUTTON_ALT		NCURSES_MOUSE_MASK(5, 0004L)
 #define	REPORT_MOUSE_POSITION	NCURSES_MOUSE_MASK(5, 0010L)
 
-#endif
+#endif	/* NCURSES_MOUSE_VERSION >= 1 */
 
 #define	ALL_MOUSE_EVENTS	(REPORT_MOUSE_POSITION - 1)
 
