@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018-2020,2021 Thomas E. Dickey                                *
+ * Copyright 2018-2023,2024 Thomas E. Dickey                                *
  * Copyright 1998-2013,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -33,7 +33,7 @@
 /*    and: Thomas E. Dickey                        1995-on                  */
 /****************************************************************************/
 
-/* $Id: MKterm.h.awk.in,v 1.82 2021/09/24 17:02:46 tom Exp $ */
+/* $Id: MKterm.h.awk.in,v 1.87 2024/12/28 21:42:15 tom Exp $ */
 
 /*
 **	term.h -- Definition of struct term
@@ -43,7 +43,7 @@
 #define NCURSES_TERM_H_incl 1
 
 #undef  NCURSES_VERSION
-#define NCURSES_VERSION "6.4"
+#define NCURSES_VERSION "6.5"
 
 #include <ncursest/ncurses_dll.h>
 
@@ -59,9 +59,10 @@ extern "C" {
 
 typedef struct screen  SCREEN;
 
+/* configured with --enable-sp-funcs? */
 #if 1
 #undef  NCURSES_SP_FUNCS
-#define NCURSES_SP_FUNCS 20230401
+#define NCURSES_SP_FUNCS 20250308
 #undef  NCURSES_SP_NAME
 #define NCURSES_SP_NAME(name) name##_sp
 
@@ -108,7 +109,7 @@ typedef int (*NCURSES_SP_OUTC)(SCREEN*, int);
 #else /* !HAVE_TERMIOS_H */
 
 /* #if HAVE_TERMIO_H */
-#if 0
+#if 1
 
 #undef  TERMIOS
 #define TERMIOS 1
@@ -119,6 +120,7 @@ typedef int (*NCURSES_SP_OUTC)(SCREEN*, int);
 #else /* !HAVE_TERMIO_H */
 
 #if (defined(_WIN32) || defined(_WIN64))
+/* configured with --enable-exp-win32? */
 #if 0
 #include <ncursest/win32_curses.h>
 #define TTY struct winconmode
@@ -139,6 +141,7 @@ typedef int (*NCURSES_SP_OUTC)(SCREEN*, int);
 #ifdef TERMIOS
 #define GET_TTY(fd, buf) tcgetattr(fd, buf)
 #define SET_TTY(fd, buf) tcsetattr(fd, TCSADRAIN, buf)
+/* configured with --enable-exp-win32? */
 #elif 0 && (defined(_WIN32) || defined(_WIN64))
 #define GET_TTY(fd, buf) _nc_console_getmode(_nc_console_fd2handle(fd),buf)
 #define SET_TTY(fd, buf) _nc_console_setmode(_nc_console_fd2handle(fd),buf)
@@ -727,9 +730,10 @@ typedef struct term {		/* describe an actual terminal */
 
 #endif /* NCURSES_INTERNALS */
 
-
+/* configured with --enable-broken_linker and reentrancy disabled */
 #if 0 && !1
 extern NCURSES_EXPORT_VAR(TERMINAL *) cur_term;
+/* reentrancy enabled */
 #elif 1
 NCURSES_WRAPPED_VAR(TERMINAL *, cur_term);
 #define cur_term   NCURSES_PUBLIC_VAR(cur_term())
@@ -737,6 +741,7 @@ NCURSES_WRAPPED_VAR(TERMINAL *, cur_term);
 extern NCURSES_EXPORT_VAR(TERMINAL *) cur_term;
 #endif
 
+/* configured with --enable-broken_linker or reentrancy enabled */
 #if 0 || 1
 NCURSES_WRAPPED_VAR(NCURSES_CONST char * const *, boolnames);
 NCURSES_WRAPPED_VAR(NCURSES_CONST char * const *, boolcodes);
@@ -784,16 +789,11 @@ extern NCURSES_EXPORT(int) _nc_read_termtype (TERMTYPE2 *, char *, int);
 extern NCURSES_EXPORT(char *) _nc_first_name (const char *const);
 extern NCURSES_EXPORT(int) _nc_name_match (const char *const, const char *const, const char *const);
 extern NCURSES_EXPORT(char *) _nc_tiparm(int, const char *, ...);
-
-#endif /* NCURSES_INTERNALS */
-
-
-/*
- * These entrypoints are used by tack 1.07.
- */
 extern NCURSES_EXPORT(const TERMTYPE *) _nc_fallback (const char *);
 extern NCURSES_EXPORT(int) _nc_read_entry (const char * const, char * const, TERMTYPE *const);
 
+#endif /* NCURSES_INTERNALS */
+
 /*
  * Normal entry points
  */
@@ -812,6 +812,7 @@ extern NCURSES_EXPORT(int) putp (const char *);
 extern NCURSES_EXPORT(int) tigetflag (const char *);
 extern NCURSES_EXPORT(int) tigetnum (const char *);
 
+/* configured without --disable-tparm-varargs? */
 #if 1 /* NCURSES_TPARM_VARARGS */
 extern NCURSES_EXPORT(char *) tparm (const char *, ...);	/* special */
 #else
@@ -819,6 +820,8 @@ extern NCURSES_EXPORT(char *) tparm (const char *, long,long,long,long,long,long
 #endif
 
 extern NCURSES_EXPORT(char *) tiparm (const char *, ...);		/* special */
+extern NCURSES_EXPORT(char *) tiparm_s (int, int, const char *, ...);	/* special */
+extern NCURSES_EXPORT(int) tiscan_s (int *, int *, const char *);	/* special */
 
 #endif /* __NCURSES_H */
 
@@ -842,6 +845,7 @@ extern NCURSES_EXPORT(int)     NCURSES_SP_NAME(putp) (SCREEN*, const char *);
 extern NCURSES_EXPORT(int)     NCURSES_SP_NAME(tigetflag) (SCREEN*, const char *);
 extern NCURSES_EXPORT(int)     NCURSES_SP_NAME(tigetnum) (SCREEN*, const char *);
 
+/* configured without --disable-tparm-varargs? */
 #if 1 /* NCURSES_TPARM_VARARGS */
 extern NCURSES_EXPORT(char *)  NCURSES_SP_NAME(tparm) (SCREEN*, const char *, ...);	/* special */
 #else
